import Hermione, { Test as HermioneTest } from 'hermione';
import { ValueOf } from 'type-fest';
import { TestStatus } from '../constants';
import { ErrorDetails, HermioneTestResult, ImageBase64, ImageInfoFull, TestError } from '../types';
import { ReporterTestResult } from './index';
export declare const getStatus: (eventName: ValueOf<Hermione['events']>, events: Hermione['events'], testResult: HermioneTestResult) => TestStatus;
export interface HermioneTestAdapterOptions {
    attempt: number;
    status: TestStatus;
}
export declare class HermioneTestAdapter implements ReporterTestResult {
    private _testResult;
    private _errorDetails;
    private _timestamp;
    private _attempt;
    private _status;
    static create<T extends HermioneTestAdapter>(this: new (testResult: HermioneTestResult, options: HermioneTestAdapterOptions) => T, testResult: HermioneTestResult, options: HermioneTestAdapterOptions): T;
    constructor(testResult: HermioneTest | HermioneTestResult, { attempt, status }: HermioneTestAdapterOptions);
    get fullName(): string;
    get skipReason(): string;
    get status(): TestStatus;
    get sessionId(): string;
    get browserId(): string;
    get imagesInfo(): ImageInfoFull[];
    get attempt(): number;
    get history(): string[];
    get error(): undefined | TestError;
    get imageDir(): string;
    get state(): {
        name: string;
    };
    get testPath(): string[];
    get id(): string;
    get screenshot(): ImageBase64 | undefined;
    get description(): string | undefined;
    get meta(): Record<string, unknown>;
    get errorDetails(): ErrorDetails | null;
    get file(): string;
    get url(): string | undefined;
    get multipleTabs(): boolean;
    get timestamp(): number | undefined;
    set timestamp(timestamp: number | undefined);
}
